@@ -1,9 +1,11 @@
 # encoding: utf-8
 import json
 import logging
+import enum
 import tkinter as tk
 from collections import defaultdict, namedtuple
 
+
 __all__ = [
     "BuilderObject",
     "EntryBaseBO",
@@ -12,7 +14,6 @@ __all__ = [
     "WidgetDescription",
     "CLASS_MAP",
     "CB_TYPES",
-    "CUSTOM_PROPERTIES",
     "TRANSLATABLE_PROPERTIES",
 ]
 
@@ -41,7 +42,6 @@ WidgetDescription = namedtuple(
 )
 
 CLASS_MAP = {}
-CUSTOM_PROPERTIES = {}
 
 
 class CB_TYPES:
@@ -58,9 +58,11 @@ class CB_TYPES:
 
 TRANSLATABLE_PROPERTIES = ["label", "text", "title"]
 
-#
-# Base class
-#
+
+class FamilyType(enum.Flag):
+    NONE = enum.auto()
+    CONTAINER = enum.auto()  # The object can have children
+    MODIFIER = enum.auto()  # The object is a modifier of another object ?
 
 
 class BuilderObject(object):
@@ -72,6 +74,7 @@ class BuilderObject(object):
     OPTIONS_STANDARD = tuple()
     OPTIONS_SPECIFIC = tuple()
     OPTIONS_CUSTOM = tuple()
+    family = FamilyType.NONE
     class_ = None
     container = False
     container_layout = False
@@ -122,6 +125,12 @@ class BuilderObject(object):
             and classname not in cls.allowed_children
         ):
             allowed = False
+
+        if not allowed:
+            # Check for new family flag
+            # Even if this object is not a container, if the child
+            # has a MODIFIER flag, it can be inserted
+            allowed = FamilyType.MODIFIER in child_builder.family
         return allowed
 
     @classmethod
@@ -239,7 +248,8 @@ class BuilderObject(object):
             description = widget.configure(pname)
             # print(description)
         except tk.TclError:
-            logger.error("Failed to get default value for property %s", pname)
+            msg = "Failed to get default value of '%s' property using configure method."
+            logger.warning(msg, pname)
             return default
 
         has_default = False
