@@ -1,20 +1,20 @@
 import awesometkinter as atk
 from pygubu.i18n import _
-from pygubu.api.v1 import register_widget, register_custom_property
+from pygubu.api.v1 import register_widget
 from pygubu.plugins.tk.tkstdwidgets import TKLabel
-from ..awesometkinter import _designer_tab_label, _plugin_uid
+from ..awesometkinter import _plugin_uid, _designer_tabs
 
 
 class AutoWrappingLabelBO(TKLabel):
     class_ = atk.label.AutoWrappingLabel
 
 
-_builder_uid = _plugin_uid + ".AutoWrappingLabel"
+_builder_uid = f"{_plugin_uid}.AutoWrappingLabel"
 register_widget(
     _builder_uid,
     AutoWrappingLabelBO,
     "AutoWrappingLabel",
-    ("ttk", _designer_tab_label),
+    _designer_tabs,
     group=1,
 )
 
@@ -28,15 +28,11 @@ class AutofitLabelBO(TKLabel):
     class_ = atk.label.AutofitLabel
 
 
-_builder_uid = _plugin_uid + ".AutofitLabel"
+_builder_uid = f"{_plugin_uid}.AutofitLabel"
 register_widget(
     _builder_uid,
     AutofitLabelBO,
     "AutofitLabel",
-    ("ttk", _designer_tab_label),
+    _designer_tabs,
     group=1,
 )
-
-register_custom_property(
-    _builder_uid, "refresh_time", "naturalnumber", help=_("milliseconds")
-)
