@@ -18,9 +18,9 @@ logger = logging.getLogger(__name__)
 #
 # tkinter widgets
 #
-_toplevel_87 = tuple()
-if tk.TkVersion >= 8.7:
-    _toplevel_87 = ("backgroundimage", "tile")
+has_tk_version_9 = tk.TkVersion >= 9
+
+_v9_frame_options = ("backgroundimage", "tile") if has_tk_version_9 else tuple()
 
 
 class TKRootBO(WmMixin, BuilderObject):
@@ -55,7 +55,7 @@ class TKRootBO(WmMixin, BuilderObject):
         "resizable",
         "iconbitmap",
         "iconphoto",
-    ) + _toplevel_87
+    ) + _v9_frame_options
     ro_properties = (
         "baseName",
         "className",
@@ -89,7 +89,7 @@ class TKToplevel(WmMixin, BuilderObject):
         "container",
         "height",
         "width",
-    ) + _toplevel_87
+    ) + _v9_frame_options
     OPTIONS_CUSTOM = (
         "title",
         "geometry",
@@ -139,7 +139,7 @@ class TKFrame(BuilderObject):
         "container",
         "height",
         "width",
-    )
+    ) + _v9_frame_options
     class_ = tk.Frame
     container = True
     container_layout = True
@@ -616,7 +616,7 @@ register_widget(
 
 class TKMenubutton(BuilderObject):
     class_ = tk.Menubutton
-    container = False
+    container = True
     OPTIONS_STANDARD = (
         "activebackground",
         "activeforeground",
@@ -940,7 +940,7 @@ class TKMenu(BuilderObject):
     command_properties = ("postcommand", "tearoffcommand")
     allow_bindings = False
 
-    def layout(self, target=None):
+    def layout(self, target=None, *, forget=False):
         pass
 
     #
@@ -1004,7 +1004,7 @@ class TKMenuitem(BuilderObject):
         index = master.index(tk.END) or 0
         # TODO: index of items is shifted if tearoff is changed
         # for now check tearoff config and recalculate index.
-        has_tearoff = True if master.type(0) == "tearoff" else False
+        has_tearoff = master.type(0) == "tearoff"
         tearoff_conf = parent.wmeta.properties.get("tearoff", "1")
         offset = 0
         if has_tearoff and tearoff_conf in ("0", "false"):
@@ -1023,7 +1023,7 @@ class TKMenuitem(BuilderObject):
     def configure(self):
         pass
 
-    def layout(self, target=None):
+    def layout(self, target=None, *, forget=False):
         pass
 
     def _connect_command(self, cpname, callback):
@@ -1051,15 +1051,18 @@ class TKMenuitem(BuilderObject):
         commands = super().code_connect_commands()
         lines.extend(commands)
         # create item
-        item_lines = self._code_render_menuitem(boparent, self.wmeta.identifier,
-                                            self.itemtype, properties)
+        item_lines = self._code_render_menuitem(
+            boparent, self.wmeta.identifier, self.itemtype, properties
+        )
         lines.extend(item_lines)
 
         for pname in complex_properties:
             lines.extend(code_bag[pname])
         return lines
 
-    def _code_render_menuitem(self, parent_bo, itemid:str, itemtype:str, properties:dict):
+    def _code_render_menuitem(
+        self, parent_bo, itemid: str, itemtype: str, properties: dict
+    ):
         lines = []
 
         targetid = parent_bo.code_identifier()
@@ -1214,7 +1217,7 @@ class TKMenuitemSubmenu(TKMenuitem):
     def configure(self):
         pass
 
-    def layout(self, target=None):
+    def layout(self, target=None, *, forget=False):
         pass
 
     def _connect_command(self, cpname, callback):
@@ -1430,7 +1433,7 @@ class TKLabelwidgetBO(BuilderObject):
     def add_child(self, bobject):
         self.widget.configure(labelwidget=bobject.widget)
 
-    def layout(self, target=None):
+    def layout(self, target=None, *, forget=False):
         pass
 
     #
@@ -1463,7 +1466,7 @@ register_widget(
 class ToplevelMenuHelperBO(BuilderObject):
     class_ = None
     container = True
-    allowed_parents = ("tk.Toplevel",)
+    allowed_parents = ("tk.Tk", "tk.Toplevel")
     maxchildren = 1
     layout_required = False
     allow_bindings = False
@@ -1475,7 +1478,7 @@ class ToplevelMenuHelperBO(BuilderObject):
     def add_child(self, bobject):
         self.widget.configure(menu=bobject.widget)
 
-    def layout(self, target=None):
+    def layout(self, target=None, *, forget=False):
         pass
 
     #
