@@ -15,7 +15,7 @@ class TkcalendarLoader(BuilderLoaderPlugin):
 
     def do_activate(self) -> bool:
         spec = importlib.util.find_spec("tkcalendar")
-        return True if spec is not None else False
+        return spec is not None
 
     def get_module_for(self, identifier: str) -> str:
         for module, identifiers in self.module_map.items():
@@ -28,3 +28,9 @@ class TkcalendarLoader(BuilderLoaderPlugin):
 
     def can_load(self, identifier: str) -> bool:
         return identifier.startswith("tkcalendar.")
+
+    def get_designer_plugin(self):
+        """Load class that implements IDesignerPlugin"""
+        from .designer.designerplugin import TkcalendarPlugin
+
+        return TkcalendarPlugin()
